@@ -1,22 +1,23 @@
 package POE::Filter::IRCD;
 
 use strict;
+use warnings;
 use Carp;
 use vars qw($VERSION);
 use base qw(POE::Filter);
 
-$VERSION = '2.31';
+$VERSION = '2.40';
 
 sub _PUT_LITERAL () { 1 }
 
 # Probably some other stuff should go here.
 
-our $g = {
+my $g = {
   space			=> qr/\x20+/o,
   trailing_space	=> qr/\x20*/o,
 };
 
-our $irc_regex = qr/^
+my $irc_regex = qr/^
   (?:
     \x3a                #  : comes before hand
     (\S+)               #  [prefix]
@@ -156,6 +157,13 @@ sub put {
   return $raw_lines;
 }
 
+sub clone {
+  my $self = shift;
+  my $nself = { };
+  $nself->{$_} = $self->{$_} for keys %{ $self };
+  $nself->{BUFFER} = [ ];
+  return bless $nself, ref $self;
+}
 
 # This thing is far from correct, dont use it.
 sub _checkargs {
@@ -206,7 +214,7 @@ A standalone version exists as L<Parse::IRC>.
 
 =over
 
-=item new
+=item C<new>
 
 Creates a new POE::Filter::IRCD object. Takes two optional arguments: 
 
@@ -220,13 +228,13 @@ Creates a new POE::Filter::IRCD object. Takes two optional arguments:
 
 =over
 
-=item get_one_start
+=item C<get_one_start>
 
-=item get_one
+=item C<get_one>
 
-=item get_pending
+=item C<get_pending>
 
-=item get
+=item C<get>
 
 Takes an arrayref which is contains lines of IRC formatted input. Returns an arrayref of hashrefs
 which represents the lines. The hashref contains the following fields:
@@ -247,7 +255,7 @@ For example, if the filter receives the following line, the following hashref is
 		raw_line => ':moo.server.net 001 lamebot :Welcome to the IRC network lamebot',
 	   }
 
-=item put
+=item C<put>
 
 Takes an arrayref containing hashrefs of IRC data and returns an arrayref containing IRC formatted lines.
 Optionally, one can specify 'colonify' to override the global colonification option.
@@ -262,7 +270,11 @@ eg.
 
   $filter->put( [ $hashref ] );
 
-=item debug
+=item C<clone>
+
+Makes a copy of the filter, and clears the copy's buffer.
+
+=item C<debug>
 
 With a true or false argument, enables or disables debug output respectively. Without an argument the behaviour is to toggle the debug status.
 
@@ -276,6 +288,12 @@ Chris Williams <chris@bingosnet.co.uk>
 
 Jonathan Steinert
 
+=head1 LICENSE
+
+Copyright E<copy> Chris Williams and Jonathan Steinert
+
+This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
+
 =head1 SEE ALSO
 
 L<POE>
@@ -291,4 +309,3 @@ L<POE::Component::IRC>
 L<Parse::IRC>
 
 =cut
-
